==> billogram-foundation-3.5.0.tgz: package/modules/components/dropdown/option-route/DropdownRouteOption.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { Link } from 'react-router';


export default ({
    block,
    displayName
} = {}) => {

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            disabled: PropTypes.bool,
            highlighted: PropTypes.bool,
            selected: PropTypes.bool,
            showArrow: PropTypes.bool,
            text: PropTypes.string,
            to: PropTypes.oneOfType([PropTypes.object, PropTypes.string])
        },

        getDefaultProps() {
            return {
                disabled: false,
                highlighted: false,
                selected: false,
                showArrow: true,
                text: '',
                to: ''
            };
        },

        onClick(evt) {
            if (this.props.disabled) {
                evt.preventDefault();
            }
        },

        renderArrow() {
            if (!this.props.showArrow) {
                return null;
            }

            return (
                <i className={ block('option-arrow') } />
            );
        },

        render() {
            const { disabled, highlighted, selected, text, to } = this.props;
            return (
                <Link
                    className={ block('option', { disabled, highlighted, selected }, ['arrow']) }
                    onClick={ this.onClick }
                    title={ text }
                    to={ to }>
                    { text }
                    { this.renderArrow() }
                </Link>
            );
        }

    });

};

==> billogram-foundation-4.6.0.tgz: package/modules/components/dropdown/option-route/DropdownRouteOption.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { Link } from 'react-router';


export default ({
    block,
    displayName
} = {}) => {

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            disabled: PropTypes.bool,
            highlighted: PropTypes.bool,
            selected: PropTypes.bool,
            showArrow: PropTypes.bool,
            text: PropTypes.node,
            to: PropTypes.oneOfType([PropTypes.object, PropTypes.string])
        },

        getDefaultProps() {
            return {
                disabled: false,
                highlighted: false,
                selected: false,
                showArrow: true,
                text: '',
                to: ''
            };
        },

        onClick(evt) {
            if (this.props.disabled) {
                evt.preventDefault();
            }
        },

        renderArrow() {
            if (!this.props.showArrow) {
                return null;
            }

            return (
                <i className={ block('option-arrow') } />
            );
        },

        render() {
            const { disabled, highlighted, selected, text, to } = this.props;
            return (
                <Link
                    className={ block('option', { disabled, highlighted, selected }, ['arrow']) }
                    onClick={ this.onClick }
                    title={ text }
                    to={ to }>
                    { text }
                    { this.renderArrow() }
                </Link>
            );
        }

    });

};
